Module: Google::Cloud::Ces

Defined in:
lib/google/cloud/ces.rb,
lib/google/cloud/ces/version.rb

Constant Summary collapse

VERSION =
"0.1.0"

Class Method Summary collapse

Class Method Details

.agent_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for AgentService.

By default, this returns an instance of Google::Cloud::Ces::V1::AgentService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the AgentService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the AgentService service. You can determine whether the method will succeed by calling agent_service_available?.

About AgentService

The service that manages agent-related resources in Gemini Enterprise for Customer Engagement (CES).

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



76
77
78
79
80
81
82
83
84
85
86
# File 'lib/google/cloud/ces.rb', line 76

def self.agent_service version: :v1, transport: :grpc, &block
  require "google/cloud/ces/#{version.to_s.downcase}"

  package_name = Google::Cloud::Ces
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Ces.const_get(package_name).const_get(:AgentService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.agent_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the AgentService service is supported by the current client. If true, you can retrieve a client object by calling agent_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the AgentService service, or if the versioned client gem needs an update to support the AgentService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/google/cloud/ces.rb', line 100

def self.agent_service_available? version: :v1, transport: :grpc
  require "google/cloud/ces/#{version.to_s.downcase}"
  package_name = Google::Cloud::Ces
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Ces.const_get package_name
  return false unless service_module.const_defined? :AgentService
  service_module = service_module.const_get :AgentService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.configure {|::Google::Cloud.configure.ces| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-ces library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



357
358
359
360
361
# File 'lib/google/cloud/ces.rb', line 357

def self.configure
  yield ::Google::Cloud.configure.ces if block_given?

  ::Google::Cloud.configure.ces
end

.session_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for SessionService.

By default, this returns an instance of Google::Cloud::Ces::V1::SessionService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the SessionService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the SessionService service. You can determine whether the method will succeed by calling session_service_available?.

About SessionService

Session service provides APIs for interacting with CES agents.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



146
147
148
149
150
151
152
153
154
155
156
# File 'lib/google/cloud/ces.rb', line 146

def self.session_service version: :v1, transport: :grpc, &block
  require "google/cloud/ces/#{version.to_s.downcase}"

  package_name = Google::Cloud::Ces
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Ces.const_get(package_name).const_get(:SessionService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.session_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the SessionService service is supported by the current client. If true, you can retrieve a client object by calling session_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the SessionService service, or if the versioned client gem needs an update to support the SessionService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/google/cloud/ces.rb', line 170

def self.session_service_available? version: :v1, transport: :grpc
  require "google/cloud/ces/#{version.to_s.downcase}"
  package_name = Google::Cloud::Ces
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Ces.const_get package_name
  return false unless service_module.const_defined? :SessionService
  service_module = service_module.const_get :SessionService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.tool_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for ToolService.

By default, this returns an instance of Google::Cloud::Ces::V1::ToolService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the ToolService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ToolService service. You can determine whether the method will succeed by calling tool_service_available?.

About ToolService

Tool service provides APIs for interacting with CES tools.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



216
217
218
219
220
221
222
223
224
225
226
# File 'lib/google/cloud/ces.rb', line 216

def self.tool_service version: :v1, transport: :grpc, &block
  require "google/cloud/ces/#{version.to_s.downcase}"

  package_name = Google::Cloud::Ces
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Ces.const_get(package_name).const_get(:ToolService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.tool_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the ToolService service is supported by the current client. If true, you can retrieve a client object by calling tool_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ToolService service, or if the versioned client gem needs an update to support the ToolService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/google/cloud/ces.rb', line 240

def self.tool_service_available? version: :v1, transport: :grpc
  require "google/cloud/ces/#{version.to_s.downcase}"
  package_name = Google::Cloud::Ces
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Ces.const_get package_name
  return false unless service_module.const_defined? :ToolService
  service_module = service_module.const_get :ToolService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.widget_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for WidgetService.

By default, this returns an instance of Google::Cloud::Ces::V1::WidgetService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the WidgetService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the WidgetService service. You can determine whether the method will succeed by calling widget_service_available?.

About WidgetService

Provides APIs for widgets to interact with CES APIs.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



286
287
288
289
290
291
292
293
294
295
296
# File 'lib/google/cloud/ces.rb', line 286

def self.widget_service version: :v1, transport: :grpc, &block
  require "google/cloud/ces/#{version.to_s.downcase}"

  package_name = Google::Cloud::Ces
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Ces.const_get(package_name).const_get(:WidgetService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.widget_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the WidgetService service is supported by the current client. If true, you can retrieve a client object by calling widget_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the WidgetService service, or if the versioned client gem needs an update to support the WidgetService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/google/cloud/ces.rb', line 310

def self.widget_service_available? version: :v1, transport: :grpc
  require "google/cloud/ces/#{version.to_s.downcase}"
  package_name = Google::Cloud::Ces
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Ces.const_get package_name
  return false unless service_module.const_defined? :WidgetService
  service_module = service_module.const_get :WidgetService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end